---
title: <span class="badge builder"></span> BuiltinRoleRef
---
# <span class="badge builder"></span> BuiltinRoleRef

## Constructor

```python
BuiltinRoleRef()
```
## Methods

### <span class="badge object-method"></span> build

Builds the object.

```python
def build() -> rolebinding.BuiltinRoleRef
```

### <span class="badge object-method"></span> name

```python
def name(name: typing.Literal["viewer", "editor", "admin"]) -> typing.Self
```

## See also

 * <span class="badge object-type-class"></span> [BuiltinRoleRef](./object-BuiltinRoleRef.md)
